@@ -13,6 +13,9 @@ class DownloadEventType(str, Enum):
     PROGRESS = "progress"
     """The download progress has been updated"""
 
+    SKIPPED = "skipped"
+    """The download has been skipped"""
+
     STARTED = "started"
     """The download has been started"""
 
@@ -45,6 +48,11 @@ class DownloadFailureEvent:
     url: str
 
 
+@dataclass(frozen=True)
+class DownloadSkipEvent(DownloadBaseEvent):
+    reason: str
+
+
 @dataclass(frozen=True)
 class DownloadStartEvent(DownloadBaseEvent):
     filesize: int
